@@ -81,6 +81,11 @@ func exampleInfo() *nfpm.Info {
 					Destination: "/etc/fake/fake2.conf",
 					Type:        files.TypeConfigNoReplace,
 				},
+				{
+					Source:      "../testdata/whatever.conf",
+					Destination: "/etc/fake/fake3.conf",
+					Type:        files.TypeConfigMissingOK,
+				},
 				{
 					Destination: "/var/log/whatever",
 					Type:        files.TypeDir,
@@ -315,6 +320,28 @@ func TestControl(t *testing.T) {
 	require.Equal(t, string(bts), w.String())
 }
 
+func TestSignatureName(t *testing.T) {
+	info := exampleInfo()
+	info.APK.Signature.KeyFile = "../internal/sign/testdata/rsa.priv"
+	info.APK.Signature.KeyName = "testkey"
+	info.APK.Signature.KeyPassphrase = "hunter2"
+	err := nfpm.PrepareForPackager(info, "apk")
+	require.NoError(t, err)
+
+	digest := sha1.New().Sum(nil) // nolint:gosec
+
+	var signatureTarGz bytes.Buffer
+	tw := tar.NewWriter(&signatureTarGz)
+	require.NoError(t, createSignatureBuilder(digest, info)(tw))
+
+	signature := extractFromTar(t, signatureTarGz.Bytes(), ".SIGN.RSA.testkey.rsa.pub")
+	err = sign.RSAVerifySHA1Digest(digest, signature, "../internal/sign/testdata/rsa.pub")
+	require.NoError(t, err)
+
+	err = Default.Package(info, io.Discard)
+	require.NoError(t, err)
+}
+
 func TestSignature(t *testing.T) {
 	info := exampleInfo()
 	info.APK.Signature.KeyFile = "../internal/sign/testdata/rsa.priv"
@@ -477,12 +504,16 @@ func TestAPKConventionalFileName(t *testing.T) {
 			Expect: "default_1.2.3_x86_64.apk",
 		},
 		{
-			Arch: "386", Version: "1.2.3", Prerelease: "git",
-			Expect: "default_1.2.3_git_x86.apk",
+			Arch: "386", Version: "1.2.3", Meta: "git",
+			Expect: "default_1.2.3-git_x86.apk",
+		},
+		{
+			Arch: "386", Version: "1.2.3", Meta: "1", Release: "10",
+			Expect: "default_1.2.3-r10-p1_x86.apk",
 		},
 		{
 			Arch: "386", Version: "1.2.3", Prerelease: "git", Release: "1",
-			Expect: "default_1.2.3_git_p1_x86.apk",
+			Expect: "default_1.2.3_git-r1_x86.apk",
 		},
 		{
 			Arch: "all", Version: "1.2.3",
@@ -490,7 +521,11 @@ func TestAPKConventionalFileName(t *testing.T) {
 		},
 		{
 			Arch: "386", Version: "1.2.3", Release: "1", Prerelease: "beta1",
-			Expect: "default_1.2.3_beta1_p1_x86.apk",
+			Expect: "default_1.2.3_beta1-r1_x86.apk",
+		},
+		{
+			Arch: "amd64", Version: "1.2.3a", Prerelease: "alpha1", Release: "47", Meta: "git-aaaccc",
+			Expect: "default_1.2.3a_alpha1-r47-git-aaaccc_x86_64.apk",
 		},
 	}
 
