@@ -681,7 +681,7 @@ func conffiles(info *nfpm.Info) []byte {
 	var confs []string
 	for _, file := range info.Contents {
 		switch file.Type {
-		case files.TypeConfig, files.TypeConfigNoReplace:
+		case files.TypeConfig, files.TypeConfigNoReplace, files.TypeConfigMissingOK:
 			confs = append(confs, files.NormalizeAbsoluteFilePath(file.Destination))
 		}
 	}
@@ -724,6 +724,9 @@ Section: {{.Info.Section}}
 Priority: {{.Info.Priority}}
 Architecture: {{ if ne .Info.Platform "linux"}}{{ .Info.Platform }}-{{ end }}{{.Info.Arch}}
 {{- /* Optional fields */ -}}
+{{- if .Info.License }}
+License: {{.Info.License}}
+{{- end }}
 {{- if .Info.Maintainer}}
 Maintainer: {{.Info.Maintainer}}
 {{- end }}
