@@ -46,6 +46,7 @@ func exampleInfo() *nfpm.Info {
 		Section:     "default",
 		Homepage:    "http://carlosbecker.com",
 		Vendor:      "nope",
+		License:     "MIT",
 		Overridables: nfpm.Overridables{
 			Depends: []string{
 				"bash",
@@ -84,6 +85,11 @@ func exampleInfo() *nfpm.Info {
 					Destination: "/etc/fake/fake2.conf",
 					Type:        files.TypeConfigNoReplace,
 				},
+				{
+					Source:      "../testdata/whatever.conf",
+					Destination: "/etc/fake/fake3.conf",
+					Type:        files.TypeConfigMissingOK,
+				},
 				{
 					Destination: "/var/log/whatever",
 					Type:        files.TypeDir,
