@@ -32,9 +32,13 @@ const (
 	// user of the package.
 	TypeConfig = "config"
 	// TypeConfigNoReplace is like TypeConfig with an added noreplace directive
-	// that is respected by RPM-based distributions. For all other packages it
-	// is handled exactly like TypeConfig.
+	// that is respected by RPM-based distributions.
+	// For all other package formats it is handled exactly like TypeConfig.
 	TypeConfigNoReplace = "config|noreplace"
+	// TypeConfigMissingOK is like TypeConfig with an added missingok directive
+	// that is respected by RPM-based distributions.
+	// For all other package formats it is handled exactly like TypeConfig.
+	TypeConfigMissingOK = "config|missingok"
 	// TypeGhost is the type of an RPM ghost file which is ignored by other packagers.
 	TypeRPMGhost = "ghost"
 	// TypeRPMDoc is the type of an RPM doc file which is ignored by other packagers.
@@ -128,7 +132,7 @@ func (c *Content) WithFileInfoDefaults(umask fs.FileMode, mtime time.Time) *Cont
 	if (cc.Type == TypeDir || cc.Type == TypeImplicitDir) && cc.FileInfo.Mode == 0 {
 		cc.FileInfo.Mode = 0o755
 	}
-	if (cc.Type == TypeDir || cc.Type == TypeImplicitDir) && cc.FileInfo.MTime.IsZero() {
+	if cc.FileInfo.MTime.IsZero() {
 		cc.FileInfo.MTime = mtime
 	}
 
@@ -289,7 +293,7 @@ func PrepareForPackager(
 			if err != nil {
 				return nil, fmt.Errorf("add tree: %w", err)
 			}
-		case TypeConfig, TypeConfigNoReplace, TypeFile, "":
+		case TypeConfig, TypeConfigNoReplace, TypeConfigMissingOK, TypeFile, "":
 			globbed, err := glob.Glob(
 				filepath.ToSlash(content.Source),
 				filepath.ToSlash(content.Destination),
@@ -490,6 +494,9 @@ func addTree(
 			c.Destination = NormalizeAbsoluteDirPath(destination)
 			c.FileInfo.Mode = info.Mode() &^ umask
 			c.FileInfo.MTime = info.ModTime()
+			if ownedByFilesystem(c.Destination) {
+				c.Type = TypeImplicitDir
+			}
 		case d.Type()&os.ModeSymlink != 0:
 			linkDestination, err := os.Readlink(path)
 			if err != nil {
@@ -506,6 +513,10 @@ func addTree(
 			c.FileInfo.Mode = d.Type() &^ umask
 		}
 
+		if tree.FileInfo != nil && tree.FileInfo.Mode != 0 && c.Type != TypeSymlink {
+			c.FileInfo.Mode = tree.FileInfo.Mode
+		}
+
 		all[c.Destination] = c.WithFileInfoDefaults(umask, mtime)
 
 		return nil
